# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-05-29 12:46
from __future__ import unicode_literals

import django_extensions.db.fields.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0017_stripecharge_manual_charge'),
    ]

    operations = [
        migrations.AddField(
            model_name='stripecustomer',
            name='sources',
            field=django_extensions.db.fields.json.JSONField(default=[]),
        ),
    ]
