# -*- coding: utf-8 -*-
__title__ = "Ro Stripe"
__version__ = "0.9.1"
__author__ = "Remigiusz Dymecki"
__license__ = "MIT"
__copyright__ = "Copyright 2019 Ro"

# Version synonym
VERSION = __version__
