# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-09-13 20:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0019_stripecustomer_default_source'),
    ]

    operations = [
        migrations.AddField(
            model_name='stripecharge',
            name='statement_descriptor',
            field=models.CharField(blank=True, max_length=22),
        ),
    ]
