# Generated by Django 2.1.11 on 2019-09-06 20:23

import django_extensions.db.fields.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0020_stripecharge_statement_descriptor'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stripecharge',
            name='stripe_refund_id',
            field=models.CharField(blank=True, db_index=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='stripecharge',
            name='stripe_response',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='stripecoupon',
            name='metadata',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict, help_text='Set of key/value pairs that you can attach to an object. It can be useful for storing additional information about the object in a structured format.'),
        ),
        migrations.AlterField(
            model_name='stripecoupon',
            name='stripe_response',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='stripecustomer',
            name='sources',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=[]),
        ),
        migrations.AlterField(
            model_name='stripecustomer',
            name='stripe_js_response',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='stripecustomer',
            name='stripe_response',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='stripesubscription',
            name='metadata',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict, help_text='https://stripe.com/docs/api/python#create_subscription-metadata'),
        ),
        migrations.AlterField(
            model_name='stripesubscription',
            name='stripe_response',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='stripesubscriptionplan',
            name='metadata',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict, help_text='A set of key/value pairs that you can attach to a plan object. It can be useful for storing additional information about the plan in a structured format.'),
        ),
        migrations.AlterField(
            model_name='stripesubscriptionplan',
            name='stripe_response',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='stripewebhook',
            name='raw_data',
            field=django_extensions.db.fields.json.JSONField(blank=True, default=dict),
        ),
    ]
